#################################################################################################################
# Name:    mx42-disable-peer-download.ps1
# Created: 26.11.2019
# Updated: 28.11.2019
#
# Copyrights by Matrix42 AG
#
#
# The PowerShell script uninstalls BranchCache if required.
#
# Example call : .\mx42-disable-peer-download.ps1  -LogFile '.\Subdepot.log'
#
# Version: 1.0
#
#################################################################################################################

param([parameter(Mandatory=$FALSE,Position=0)]
	  [String] $LogFile=".\Disable-Peer-Download.log"
)

#################################################################################################################

. ".\mx42-common.ps1"

StartCapture $LogFile


function show_params
{
    Write-Host "Script mx42-disable-peer-download.ps1"
    Write-Host "Given Parameters:"
    Write-Host "LogFile....................: $LogFile"
}

# Import the server manager
Import-Module servermanager

# Log parameters
show_params


#################################################################################################################
# Disable Configurator$ for BranchCache
#################################################################################################################
net share "Configurator$" /Cache:Manual


#################################################################################################################
# Disable Firewall rules
#################################################################################################################

# REMOVE COMMENT IF YOU WANT TO REVERT ALL CHANGES FROM INSTALLATION

<#
Disable-NetFirewallRule -Name Microsoft-Windows-PeerDist-HttpTrans-In
Disable-NetFirewallRule -Name Microsoft-Windows-PeerDist-HttpTrans-Out
Disable-NetFirewallRule -Name Microsoft-Windows-PeerDist-WSD-In
Disable-NetFirewallRule -Name Microsoft-Windows-PeerDist-WSD-Out
#>

#################################################################################################################
# UNINSTALL SERVERROLE
#################################################################################################################

# REMOVE COMMENT IF YOU WANT TO REVERT ALL CHANGES FROM INSTALLATION

<#
# Check if BranchCache file service is installed. If so uninstall it
$BranchCacheFileServiceIsInstalled = (Get-WindowsFeature FS-BranchCache).Installed
if($BranchCacheFileServiceIsInstalled -eq $true)
{
	Write-Host "The BranchCache file service is installed on this machine. Continue with uninstallation..."
	Uninstall-WindowsFeature FS-BranchCache
}else{
	Write-Host "The BranchCache file service is not installed on this machine. Skip uninstallation..."
}

# Check if BranchCache feature is installed. If so uninstall it
$BranchCacheFeatureIsInstalled = (Get-WindowsFeature BranchCache).Installed
if($BranchCacheFeatureIsInstalled -eq $true)
{
	Write-Host "The BranchCache feature is installed on this machine. Continue with uninstallation..."
	Uninstall-WindowsFeature BranchCache
}else{
	Write-Host "The BranchCache feature is not installed on this machine. Skip uninstallation..."
}
#>

#################################################################################################################
# Check that BranchCache is uninstalled
#################################################################################################################

# REMOVE COMMENT IF YOU WANT TO REVERT ALL CHANGES FROM INSTALLATION

<#
Write-Host "Check BranchCache"
$BranchCacheIsEnabled = (Get-bcstatus).BranchCacheIsEnabled
if($BranchCacheIsEnabled -eq $false)
{
	Write-Host -ForegroundColor Green "BranchCache disabled successfully"
	exit 0
}else
{
	Write-Host "Error: BranchCache was not uninstalled correctly"
	exit 1
}
#>

#################################################################################################################


# Catch exceptions

trap [Exception]
{
    Write-Host -ForegroundColor Red "Error: $($_.Exception.Message)"
	exit 1
}

# SIG # Begin signature block
# MIIYEQYJKoZIhvcNAQcCoIIYAjCCF/4CAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCA/kiwM8g25FZQK
# JvJGNg6wbD7gSuwxzLmvjlANWe93jqCCEsgwggPuMIIDV6ADAgECAhB+k+v7fMZO
# WepLmnfUBvw7MA0GCSqGSIb3DQEBBQUAMIGLMQswCQYDVQQGEwJaQTEVMBMGA1UE
# CBMMV2VzdGVybiBDYXBlMRQwEgYDVQQHEwtEdXJiYW52aWxsZTEPMA0GA1UEChMG
# VGhhd3RlMR0wGwYDVQQLExRUaGF3dGUgQ2VydGlmaWNhdGlvbjEfMB0GA1UEAxMW
# VGhhd3RlIFRpbWVzdGFtcGluZyBDQTAeFw0xMjEyMjEwMDAwMDBaFw0yMDEyMzAy
# MzU5NTlaMF4xCzAJBgNVBAYTAlVTMR0wGwYDVQQKExRTeW1hbnRlYyBDb3Jwb3Jh
# dGlvbjEwMC4GA1UEAxMnU3ltYW50ZWMgVGltZSBTdGFtcGluZyBTZXJ2aWNlcyBD
# QSAtIEcyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsayzSVRLlxwS
# CtgleZEiVypv3LgmxENza8K/LlBa+xTCdo5DASVDtKHiRfTot3vDdMwi17SUAAL3
# Te2/tLdEJGvNX0U70UTOQxJzF4KLabQry5kerHIbJk1xH7Ex3ftRYQJTpqr1SSwF
# eEWlL4nO55nn/oziVz89xpLcSvh7M+R5CvvwdYhBnP/FA1GZqtdsn5Nph2Upg4XC
# YBTEyMk7FNrAgfAfDXTekiKryvf7dHwn5vdKG3+nw54trorqpuaqJxZ9YfeYcRG8
# 4lChS+Vd+uUOpyyfqmUg09iW6Mh8pU5IRP8Z4kQHkgvXaISAXWp4ZEXNYEZ+VMET
# fMV58cnBcQIDAQABo4H6MIH3MB0GA1UdDgQWBBRfmvVuXMzMdJrU3X3vP9vsTIAu
# 3TAyBggrBgEFBQcBAQQmMCQwIgYIKwYBBQUHMAGGFmh0dHA6Ly9vY3NwLnRoYXd0
# ZS5jb20wEgYDVR0TAQH/BAgwBgEB/wIBADA/BgNVHR8EODA2MDSgMqAwhi5odHRw
# Oi8vY3JsLnRoYXd0ZS5jb20vVGhhd3RlVGltZXN0YW1waW5nQ0EuY3JsMBMGA1Ud
# JQQMMAoGCCsGAQUFBwMIMA4GA1UdDwEB/wQEAwIBBjAoBgNVHREEITAfpB0wGzEZ
# MBcGA1UEAxMQVGltZVN0YW1wLTIwNDgtMTANBgkqhkiG9w0BAQUFAAOBgQADCZuP
# ee9/WTCq72i1+uMJHbtPggZdN1+mUp8WjeockglEbvVt61h8MOj5aY0jcwsSb0ep
# rjkR+Cqxm7Aaw47rWZYArc4MTbLQMaYIXCp6/OJ6HVdMqGUY6XlAYiWWbsfHN2qD
# IQiOQerd2Vc/HXdJhyoWBl6mOGoiEqNRGYN+tjCCBKMwggOLoAMCAQICEA7P9DjI
# /r81bgTYapgbGlAwDQYJKoZIhvcNAQEFBQAwXjELMAkGA1UEBhMCVVMxHTAbBgNV
# BAoTFFN5bWFudGVjIENvcnBvcmF0aW9uMTAwLgYDVQQDEydTeW1hbnRlYyBUaW1l
# IFN0YW1waW5nIFNlcnZpY2VzIENBIC0gRzIwHhcNMTIxMDE4MDAwMDAwWhcNMjAx
# MjI5MjM1OTU5WjBiMQswCQYDVQQGEwJVUzEdMBsGA1UEChMUU3ltYW50ZWMgQ29y
# cG9yYXRpb24xNDAyBgNVBAMTK1N5bWFudGVjIFRpbWUgU3RhbXBpbmcgU2Vydmlj
# ZXMgU2lnbmVyIC0gRzQwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCi
# Yws5RLi7I6dESbsO/6HwYQpTk7CY260sD0rFbv+GPFNVDxXOBD8r/amWltm+YXkL
# W8lMhnbl4ENLIpXuwitDwZ/YaLSOQE/uhTi5EcUj8mRY8BUyb05Xoa6IpALXKh7N
# S+HdY9UXiTJbsF6ZWqidKFAOF+6W22E7RVEdzxJWC5JH/Kuu9mY9R6xwcueS51/N
# ELnEg2SUGb0lgOHo0iKl0LoCeqF3k1tlw+4XdLxBhircCEyMkoyRLZ53RB9o1qh0
# d9sOWzKLVoszvdljyEmdOsXF6jML0vGjG/SLvtmzV4s73gSneiKyJK4ux3DFvk6D
# Jgj7C72pT5kI4RAocqrNAgMBAAGjggFXMIIBUzAMBgNVHRMBAf8EAjAAMBYGA1Ud
# JQEB/wQMMAoGCCsGAQUFBwMIMA4GA1UdDwEB/wQEAwIHgDBzBggrBgEFBQcBAQRn
# MGUwKgYIKwYBBQUHMAGGHmh0dHA6Ly90cy1vY3NwLndzLnN5bWFudGVjLmNvbTA3
# BggrBgEFBQcwAoYraHR0cDovL3RzLWFpYS53cy5zeW1hbnRlYy5jb20vdHNzLWNh
# LWcyLmNlcjA8BgNVHR8ENTAzMDGgL6AthitodHRwOi8vdHMtY3JsLndzLnN5bWFu
# dGVjLmNvbS90c3MtY2EtZzIuY3JsMCgGA1UdEQQhMB+kHTAbMRkwFwYDVQQDExBU
# aW1lU3RhbXAtMjA0OC0yMB0GA1UdDgQWBBRGxmmjDkoUHtVM2lJjFz9eNrwN5jAf
# BgNVHSMEGDAWgBRfmvVuXMzMdJrU3X3vP9vsTIAu3TANBgkqhkiG9w0BAQUFAAOC
# AQEAeDu0kSoATPCPYjA3eKOEJwdvGLLeJdyg1JQDqoZOJZ+aQAMc3c7jecshaAba
# tjK0bb/0LCZjM+RJZG0N5sNnDvcFpDVsfIkWxumy37Lp3SDGcQ/NlXTctlzevTcf
# Q3jmeLXNKAQgo6rxS8SIKZEOgNER/N1cdm5PXg5FRkFuDbDqOJqxOtoJcRD8HHm0
# gHusafT9nLYMFivxf1sJPZtb4hbKE4FtAC44DagpjyzhsvRaqQGvFZwsL0kb2yK7
# w/54lFHDhrGCiF3wPbRRoXkzKy57udwgCRNx62oZW8/opTBXLIlJP7nPf8m/PiJo
# Y1OavWl0rMUdPH+S4MO8HNgEdTCCBM4wggO2oAMCAQICED3L9ZzvVRhJCatCMCxN
# ktQwDQYJKoZIhvcNAQELBQAwfzELMAkGA1UEBhMCVVMxHTAbBgNVBAoTFFN5bWFu
# dGVjIENvcnBvcmF0aW9uMR8wHQYDVQQLExZTeW1hbnRlYyBUcnVzdCBOZXR3b3Jr
# MTAwLgYDVQQDEydTeW1hbnRlYyBDbGFzcyAzIFNIQTI1NiBDb2RlIFNpZ25pbmcg
# Q0EwHhcNMTgwMzE1MDAwMDAwWhcNMjEwNTEyMjM1OTU5WjBmMQswCQYDVQQGEwJE
# RTEPMA0GA1UECAwGSGVzc2VuMRowGAYDVQQHDBFGcmFua2Z1cnQgYW0gTWFpbjEU
# MBIGA1UECgwLTWF0cml4NDIgQUcxFDASBgNVBAMMC01hdHJpeDQyIEFHMIIBIjAN
# BgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwWJCiaJ1Ji13WoMVZb2z9NhHjp4k
# tZGkzetOBTFD3ZZdQCAAe9h2QG/HLpGi5r7uZCn+B5NK5GhBXKx+xM9rKWrhDtS4
# 9L6f7pDTwarMiCGI+O+kQd8EdLj5/0xCgoH2ee4eHTtagEki3eibnHzVPYDH5nRl
# Zlo6mChRtVFAJoZFH2MvbQumKh3YV57xw8/ZWb/2ZBX+S/M5E1wVN9FyUadrSknK
# b9Tt6d60ZnOEVGcHUcudUQZIhZt8PhiAe78u7dkw8uHgcXikauemLfs0u6+jVUtd
# /hBl4oUtJDGFe5dfejXBOjwiUGCsPH+RkgjKR7P3rXaAwvZiWmgUKRD0SQIDAQAB
# o4IBXTCCAVkwCQYDVR0TBAIwADAOBgNVHQ8BAf8EBAMCB4AwKwYDVR0fBCQwIjAg
# oB6gHIYaaHR0cDovL3N2LnN5bWNiLmNvbS9zdi5jcmwwYQYDVR0gBFowWDBWBgZn
# gQwBBAEwTDAjBggrBgEFBQcCARYXaHR0cHM6Ly9kLnN5bWNiLmNvbS9jcHMwJQYI
# KwYBBQUHAgIwGQwXaHR0cHM6Ly9kLnN5bWNiLmNvbS9ycGEwEwYDVR0lBAwwCgYI
# KwYBBQUHAwMwVwYIKwYBBQUHAQEESzBJMB8GCCsGAQUFBzABhhNodHRwOi8vc3Yu
# c3ltY2QuY29tMCYGCCsGAQUFBzAChhpodHRwOi8vc3Yuc3ltY2IuY29tL3N2LmNy
# dDAfBgNVHSMEGDAWgBSWO1PweTOXr32D7y4rzMq3hh5yZjAdBgNVHQ4EFgQUQm1H
# y/FoRTLQkgRhUUTEyrwxzD4wDQYJKoZIhvcNAQELBQADggEBAFj1SKiiu0eqW/E/
# s9DxT/O9thl0ZOjlFH+2cVBwuougWdZXz/xDPh4u4x0cffqtftSuEX388b1jm+6v
# NnTFzxXO11DurLaG6YO3A+Oau65HM9v7GN/VdJPCV+ChIcWcKcnrmMT5A5YoPFLH
# vvj55Zf0agP9Dpy1emufXJPIwQnts744QGIeco4ixX/DNnsrRGAaW6eKyNTTEFtX
# 5ETi6Y3gztPHgxrDh20Zg+mDVvqtWCCNY3xB3m87jZolhLgE4by5+wdjORgno95e
# HTaKcThb6xx552ULS5PkSk7x1ZJTztlxSEMNr/a8jevCguMPpWld1oCica2N+Z49
# /AgJ/VcwggVZMIIEQaADAgECAhA9eNf5dklgsmF99PAeyoYqMA0GCSqGSIb3DQEB
# CwUAMIHKMQswCQYDVQQGEwJVUzEXMBUGA1UEChMOVmVyaVNpZ24sIEluYy4xHzAd
# BgNVBAsTFlZlcmlTaWduIFRydXN0IE5ldHdvcmsxOjA4BgNVBAsTMShjKSAyMDA2
# IFZlcmlTaWduLCBJbmMuIC0gRm9yIGF1dGhvcml6ZWQgdXNlIG9ubHkxRTBDBgNV
# BAMTPFZlcmlTaWduIENsYXNzIDMgUHVibGljIFByaW1hcnkgQ2VydGlmaWNhdGlv
# biBBdXRob3JpdHkgLSBHNTAeFw0xMzEyMTAwMDAwMDBaFw0yMzEyMDkyMzU5NTla
# MH8xCzAJBgNVBAYTAlVTMR0wGwYDVQQKExRTeW1hbnRlYyBDb3Jwb3JhdGlvbjEf
# MB0GA1UECxMWU3ltYW50ZWMgVHJ1c3QgTmV0d29yazEwMC4GA1UEAxMnU3ltYW50
# ZWMgQ2xhc3MgMyBTSEEyNTYgQ29kZSBTaWduaW5nIENBMIIBIjANBgkqhkiG9w0B
# AQEFAAOCAQ8AMIIBCgKCAQEAl4MeABavLLHSCMTXaJNRYB5x9uJHtNtYTSNiarS/
# WhtR96MNGHdou9g2qy8hUNqe8+dfJ04LwpfICXCTqdpcDU6kDZGgtOwUzpFyVC7O
# o9tE6VIbP0E8ykrkqsDoOatTzCHQzM9/m+bCzFhqghXuPTbPHMWXBySO8Xu+MS09
# bty1mUKfS2GVXxxw7hd924vlYYl4x2gbrxF4GpiuxFVHU9mzMtahDkZAxZeSitFT
# p5lbhTVX0+qTYmEgCscwdyQRTWKDtrp7aIIx7mXK3/nVjbI13Iwrb2pyXGCEnPIM
# lF7AVlIASMzT+KV93i/XE+Q4qITVRrgThsIbnepaON2b2wIDAQABo4IBgzCCAX8w
# LwYIKwYBBQUHAQEEIzAhMB8GCCsGAQUFBzABhhNodHRwOi8vczIuc3ltY2IuY29t
# MBIGA1UdEwEB/wQIMAYBAf8CAQAwbAYDVR0gBGUwYzBhBgtghkgBhvhFAQcXAzBS
# MCYGCCsGAQUFBwIBFhpodHRwOi8vd3d3LnN5bWF1dGguY29tL2NwczAoBggrBgEF
# BQcCAjAcGhpodHRwOi8vd3d3LnN5bWF1dGguY29tL3JwYTAwBgNVHR8EKTAnMCWg
# I6Ahhh9odHRwOi8vczEuc3ltY2IuY29tL3BjYTMtZzUuY3JsMB0GA1UdJQQWMBQG
# CCsGAQUFBwMCBggrBgEFBQcDAzAOBgNVHQ8BAf8EBAMCAQYwKQYDVR0RBCIwIKQe
# MBwxGjAYBgNVBAMTEVN5bWFudGVjUEtJLTEtNTY3MB0GA1UdDgQWBBSWO1PweTOX
# r32D7y4rzMq3hh5yZjAfBgNVHSMEGDAWgBR/02Wnwt3su/AwCfNDOfoCrzMxMzAN
# BgkqhkiG9w0BAQsFAAOCAQEAE4UaHmmpN/egvaSvfh1hU/6djF4MpnUeeBcj3f3s
# GgNVOftxlcdlWqeOMNJEWmHbcG/aIQXCLnO6SfHRk/5dyc1eA+CJnj90Htf3OIup
# 1s+7NS8zWKiSVtHITTuC5nmEFvwosLFH8x2iPu6H2aZ/pFalP62ELinefLyoqqM9
# BAHqupOiDlAiKRdMh+Q6EV/WpCWJmwVrL7TJAUwnewusGQUioGAVP9rJ+01Mj/ty
# Z3f9J5THujUOiEn+jf0or0oSvQ2zlwXeRAwV+jYrA9zBUAHxoRFdFOXivSdLVL4r
# hF4PpsN0BQrvl8OJIrEfd/O9zUPU8UypP7WLhK9k8tAUITGCBJ8wggSbAgEBMIGT
# MH8xCzAJBgNVBAYTAlVTMR0wGwYDVQQKExRTeW1hbnRlYyBDb3Jwb3JhdGlvbjEf
# MB0GA1UECxMWU3ltYW50ZWMgVHJ1c3QgTmV0d29yazEwMC4GA1UEAxMnU3ltYW50
# ZWMgQ2xhc3MgMyBTSEEyNTYgQ29kZSBTaWduaW5nIENBAhA9y/Wc71UYSQmrQjAs
# TZLUMA0GCWCGSAFlAwQCAQUAoIHOMBkGCSqGSIb3DQEJAzEMBgorBgEEAYI3AgEE
# MBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3AgEVMC8GCSqGSIb3DQEJBDEiBCAK
# her2jDMlEtQvmW8pu53Fs9rNmBEABSPIba360xotxDBiBgorBgEEAYI3AgEMMVQw
# UqA2gDQATQBhAHQAcgBpAHgANAAyACAAQwBsAGkAZQBuAHQAIABNAGEAbgBhAGcA
# ZQBtAGUAbgB0oRiAFmh0dHA6Ly93d3cubWF0cml4NDIuZGUwDQYJKoZIhvcNAQEB
# BQAEggEASGBnZ+5/oa+KxAmb+VJ6vjG0TVd5tQFjFmw/3/vrqd7yclp29ycTMw0R
# l61KIyemQajClbfKnW/wLZfTk4KTqYIc8n2r0wSVy4BFXZSJ/hvPFd8xT0iwpklg
# s/+WTJylYfRDb8UIVNuwVminBNujKgkH1KEURsm52QifbqLIjSkhstx8937fYLdr
# 2HtzRuGtaH69Lal6koH9IBzQKo2rAeZr/eEqP6IHYBLCxJui9NsZ3s8YRKUIJDA1
# PqrYw+un6aCVbc1xRbPUH0xAwUSUhyWAhb9RaxXusacJsSYRQUyrtGeA96ECfnTy
# Vq9lFBpkxhA/CmugG9moKYMtF+mJZqGCAgswggIHBgkqhkiG9w0BCQYxggH4MIIB
# 9AIBATByMF4xCzAJBgNVBAYTAlVTMR0wGwYDVQQKExRTeW1hbnRlYyBDb3Jwb3Jh
# dGlvbjEwMC4GA1UEAxMnU3ltYW50ZWMgVGltZSBTdGFtcGluZyBTZXJ2aWNlcyBD
# QSAtIEcyAhAOz/Q4yP6/NW4E2GqYGxpQMAkGBSsOAwIaBQCgXTAYBgkqhkiG9w0B
# CQMxCwYJKoZIhvcNAQcBMBwGCSqGSIb3DQEJBTEPFw0xOTEyMDIxMzQ3MTNaMCMG
# CSqGSIb3DQEJBDEWBBR1d8fniGT9dw9EaM4mX1aV3lZGKDANBgkqhkiG9w0BAQEF
# AASCAQBjyYQC18BBe+SRHytZjPyePpApH6luckfQTagI80pmDQm8qOTHJpOdjBTk
# 7hKNNz9ESNPe8wA25H7Y/AIMwKswGVz+DAlcBHjLOr0yJfXq4XuCrTnS9szJuGHm
# xJ/FP4uTg01MejAPxDs1bdPqRiOXjEFs+w7qc3MGjHTkscDn22VlMkFYW21uBFZL
# SPBg5QrM/7LtSixD+uV7Af8goKU33g32kwwh6iJirEcE2seQSAPtxjsg7e1MWj51
# clL3elphlUcAyeto4SecaHkCwXCI1gTSO7MhbPG1Sa/dPO0sxaIDfohe1uq3cTkC
# vbQkBqMvea07sTuRsdyDMwGZ8KzO
# SIG # End signature block
